import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import requests
import pandas as pd
from loguru import logger


# report_type income 利润表
# cash_flow 现金流量
# balance 资产负债


def get_xue_qiu_report(symbol, report_type, cookie, count, period_type):
    # 请求 URL
    url = (f"https://stock.xueqiu.com/v5/stock/finance/cn/{report_type}.json?symbol={symbol}&type={period_type}"
           f"&is_detail=true&count={count}")

    # 请求头（关键是 cookies）
    headers = {
        "accept": "application/json, text/plain, */*",
        "accept-language": "zh-CN,zh;q=0.9",
        "origin": "https://xueqiu.com",
        "referer": f"https://xueqiu.com/snowman/S/{symbol}/detail",
        "sec-fetch-mode": "cors",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64)",
        # ⚠ 替换为你浏览器访问雪球后的 Cookie（需含 xq_a_token）
        "cookie": cookie,
    }

    # 发送请求
    response = requests.get(url, headers=headers)

    # 检查结果
    if response.status_code == 200:
        data = response.json()

        # 提取财报数据列表
        raw_list = data['data']['list']
        processed_list = []

        for entry in raw_list:
            flat_entry = {}
            for key, value in entry.items():
                if isinstance(value, list) and len(value) == 2:
                    # 处理列表字段：提取两个值，空则填 0
                    v0 = value[0] if value[0] is not None else 0
                    v1 = value[1] if value[1] is not None else 0
                    flat_entry[key] = v0
                    flat_entry[key + "_chg"] = round(v1 * 100, 2)
                elif value is None:
                    # 整个字段为空，设置为 0 和 0（变化量）
                    flat_entry[key] = 0
                else:
                    flat_entry[key] = value
            processed_list.append(flat_entry)

        # 转换为 DataFrame
        df = pd.DataFrame(processed_list)
        return df

    else:
        logger.error("请求失败，状态码:{}", response.status_code)
        return pd.DataFrame()


import mns_common.component.cookie.cookie_info_service as cookie_info_service

if __name__ == '__main__':
    cash_flow_df = get_xue_qiu_report('SZ301662', 'cash_flow', cookie_info_service.get_xue_qiu_cookie(), 1, 'all')
    income_df = get_xue_qiu_report('SZ301662', 'income', cookie_info_service.get_xue_qiu_cookie(), 1, 'all')
    balance_df = get_xue_qiu_report('SZ301662', 'balance', cookie_info_service.get_xue_qiu_cookie(), 1, 'all')
    pass



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger

import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.data.data_init_api as data_init_api
import pandas as pd
from datetime import time
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.k_line.common.k_line_common_service_api as k_line_common_service_api
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.db_util as db_util

mongodb_util = MongodbUtil('27017')

realtime_quotes_now_zt_new_kc_open_field = ['_id',
                                            'symbol',
                                            'name',
                                            'chg',
                                            'quantity_ratio',
                                            'amount_level',
                                            'real_exchange',
                                            'sum_main_inflow_disk',
                                            'disk_diff_amount',
                                            'flow_mv_level',
                                            'total_mv_level',
                                            'today_chg',
                                            'industry',
                                            'first_sw_industry',
                                            'second_sw_industry',
                                            'third_sw_industry',
                                            'ths_concept_name',
                                            'ths_concept_code',
                                            'em_industry',
                                            'disk_ratio',
                                            'company_type',
                                            'reference_main_inflow',
                                            'main_inflow_multiple', 'super_main_inflow_multiple',
                                            'disk_diff_amount_exchange', 'exchange', 'amount', 'today_main_net_inflow',
                                            'today_main_net_inflow_ratio', 'super_large_order_net_inflow',
                                            'super_large_order_net_inflow_ratio', 'large_order_net_inflow',
                                            'large_order_net_inflow_ratio', 'now_price',
                                            'high', 'low', 'open', 'yesterday_price',
                                            'volume', 'total_mv', 'flow_mv',
                                            'outer_disk', 'inner_disk',
                                            'classification', 'str_now_date', 'number', 'str_day',
                                            'yesterday_high_chg',
                                            'ths_concept_sync_day', 'mv_circulation_ratio',
                                            'large_inflow_multiple', 'real_main_inflow_multiple',
                                            'max_real_main_inflow_multiple', 'list_date',
                                            'real_super_main_inflow_multiple', 'real_flow_mv',
                                            'real_disk_diff_amount_exchange', 'no_open_data']


def sync_all_kc_zt_data(str_day, symbols):
    if symbols is None:
        query_daily = {'date': date_handle_util.no_slash_date(str_day),
                       "chg": {"$gte": common_service_fun_api.ZT_CHG}}
    else:
        query_daily = {'date': date_handle_util.no_slash_date(str_day),
                       'symbol': {"$in": symbols},
                       "chg": {"$gte": common_service_fun_api.ZT_CHG}}

    kc_stock_qfq_daily = mongodb_util.find_query_data(db_name_constant.STOCK_QFQ_DAILY, query_daily)
    if data_frame_util.is_empty(kc_stock_qfq_daily):
        logger.error("无k线数据:{}", symbols)
        return

    kc_stock_qfq_daily = company_common_service_new_api.amend_ths_industry(kc_stock_qfq_daily)

    for stock_one in kc_stock_qfq_daily.itertuples():
        try:

            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'industry'] = stock_one.industry
            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'first_sw_industry'] = stock_one.first_sw_industry
            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily[
                    'symbol'] == stock_one.symbol, 'second_sw_industry'] = stock_one.second_sw_industry
            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'third_sw_industry'] = stock_one.third_sw_industry

            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'list_date'] = stock_one.list_date

            str_day_date = date_handle_util.str_to_date(str_day, '%Y-%m-%d')

            list_date = date_handle_util.str_to_date(str(stock_one.list_date).replace(".0", ""), '%Y%m%d')

            # 计算日期差值 距离现在上市时间
            kc_stock_qfq_daily.loc[
                kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'diff_days'] = (str_day_date - list_date).days

            last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)

            query_high_chg = {'chg': {"$gte": 11}, 'date': date_handle_util.no_slash_date(last_trade_day),
                              "symbol": stock_one.symbol}
            yesterday_high_chg = mongodb_util.exist_data_query('stock_qfq_daily', query_high_chg)
            if yesterday_high_chg:
                kc_stock_qfq_daily.loc[
                    kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'yesterday_high_chg'] = True
            else:
                kc_stock_qfq_daily.loc[
                    kc_stock_qfq_daily['symbol'] == stock_one.symbol, 'yesterday_high_chg'] = False

        except BaseException as e:
            logger.error("出现异常:{},{},{}", e, str_day, stock_one.symbol)

    mongodb_util.save_mongo(kc_stock_qfq_daily, 'kc_stock_qfq_daily')
    kc_stock_qfq_daily = kc_stock_qfq_daily.loc[(kc_stock_qfq_daily['classification'].isin(['K', 'C', 'X']))
                                                | (kc_stock_qfq_daily['name'].str.startswith('C'))]
    kc_stock_qfq_daily = common_service_fun_api.exclude_new_stock(kc_stock_qfq_daily)

    kc_stock_qfq_daily = kc_stock_qfq_daily.sort_values(by=['chg'], ascending=False)

    for kc_one in kc_stock_qfq_daily.itertuples():
        try:
            db_name = 'realtime_quotes_now_' + str_day
            logger.info("同步高涨幅开盘日期和代码:{},{}", str_day, kc_one.symbol)

            query_real_time = {'symbol': kc_one.symbol}
            db = db_util.get_db(str_day)
            realtime_quotes_now_kc = db.find_query_data(db_name, query_real_time)
            stock_name = kc_one.name
            if stock_name.startswith('N'):
                continue
            if realtime_quotes_now_kc.shape[0] == 0:
                logger.error("当期日期代码无开盘数据:{},{}", str_day, kc_one.symbol)
                continue
            # 同步当天高涨幅集合竞价数据
            one_symbol_day_open_data(realtime_quotes_now_kc, kc_one, str_day)
        except BaseException as e:
            logger.error("出现异常:{},{},{}", e, str_day, kc_one.symbol)


# k c x 高涨幅当天开盘数据
def one_symbol_day_open_data(realtime_quotes_now_kc, kc_one, str_day):
    realtime_quotes_now_kc = realtime_quotes_now_kc.sort_values(by=['_id'], ascending=True)
    realtime_quotes_now_kc = realtime_quotes_now_kc.loc[realtime_quotes_now_kc['str_now_date'] >= str_day + " 09:26:00"]
    realtime_quotes_now_zt_new_kc_open = realtime_quotes_now_kc.iloc[0:1]
    _id = list(realtime_quotes_now_zt_new_kc_open['_id'])[0]
    str_now_date = _id[7:26]
    now_date = date_handle_util.str_to_date(str_now_date, "%Y-%m-%d %H:%M:%S")
    now_date_time = now_date.time()
    target_time_09_31 = time(9, 31)
    realtime_quotes_now_zt_new_kc_open_copy = realtime_quotes_now_zt_new_kc_open.copy()

    if now_date_time > target_time_09_31:
        logger.error("当期日期代码无开盘数据:{},{}", str_day, kc_one.symbol)
        realtime_quotes_now_zt_new_kc_open_copy.loc[:, 'no_open_data'] = True
    else:
        realtime_quotes_now_zt_new_kc_open_copy.loc[:, 'no_open_data'] = False
        #

    realtime_quotes_now_zt_new_kc_open_copy.loc[:, 'yesterday_high_chg'] = kc_one.yesterday_high_chg
    realtime_quotes_now_zt_new_kc_open_copy.loc[:, 'today_chg'] = kc_one.chg
    realtime_quotes_now_zt_new_kc_open_copy.loc[:, 'str_day'] = str_day
    realtime_quotes_now_zt_new_kc_open_copy = company_common_service_new_api.amend_ths_industry(
        realtime_quotes_now_zt_new_kc_open_copy)
    realtime_quotes_now_zt_new_kc_open_copy = handle_init_real_time_quotes_data(
        realtime_quotes_now_zt_new_kc_open_copy.copy(),
        str_now_date,
        1)
    if data_frame_util.is_empty(realtime_quotes_now_zt_new_kc_open_copy):
        return None
    realtime_quotes_now_zt_new_kc_open_copy = realtime_quotes_now_zt_new_kc_open_copy[
        realtime_quotes_now_zt_new_kc_open_field]

    # 将日期数值转换为日期时间格式
    realtime_quotes_now_zt_new_kc_open_copy['list_date_01'] = pd.to_datetime(
        realtime_quotes_now_zt_new_kc_open_copy['list_date'],
        format='%Y%m%d')
    # 将日期字符串转换为日期时间格式
    realtime_quotes_now_zt_new_kc_open_copy['str_day_01'] = pd.to_datetime(
        realtime_quotes_now_zt_new_kc_open_copy['str_day'],
        format='%Y-%m-%d')

    # 计算日期差值 距离现在上市时间
    realtime_quotes_now_zt_new_kc_open_copy['diff_days'] = realtime_quotes_now_zt_new_kc_open_copy.apply(
        lambda row: (row['str_day_01'] - row['list_date_01']).days, axis=1)

    del realtime_quotes_now_zt_new_kc_open_copy['str_day_01']
    del realtime_quotes_now_zt_new_kc_open_copy['list_date_01']

    deal_days = k_line_common_service_api.get_deal_days(str_day, kc_one.symbol)

    realtime_quotes_now_zt_new_kc_open_copy['deal_days'] = deal_days

    mongodb_util.save_mongo(realtime_quotes_now_zt_new_kc_open_copy, db_name_constant.KCX_HIGH_CHG_OPEN_DATA)


# 初始化数据
def handle_init_real_time_quotes_data(real_time_quotes_now, str_now_date, number):
    #  exclude b symbol
    real_time_quotes_now = common_service_fun_api.exclude_b_symbol(real_time_quotes_now.copy())
    #  classification symbol
    real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now.copy())
    #  calculate parameter
    real_time_quotes_now = data_init_api.calculate_parameter_factor(real_time_quotes_now.copy())

    real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['amount'] != 0]
    real_time_quotes_now['str_now_date'] = str_now_date
    real_time_quotes_now['number'] = number
    return real_time_quotes_now



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
from datetime import datetime
import mns_common.utils.data_frame_util as data_frame_util
import pandas as pd
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.component.common_service_fun_api as common_service_fun_api
from loguru import logger
import mns_common.utils.date_handle_util as date_handle_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_scheduler.k_line.common.k_line_common_api as k_line_common_api

mongodb_util = MongodbUtil('27017')


def ths_zt_pool(str_day, real_time_quotes_all_stocks):
    '''
    获取请求头
    :param str_day: 日期
    :param real_time_quotes_all_stocks: 实时行情
    :return:
    '''
    now_date = datetime.now()
    now_day_str_day = now_date.strftime('%Y-%m-%d')
    ths_zt_pool_df = ths_stock_zt_pool_api.get_zt_reason(str_day)
    ths_zt_pool_df_copy = ths_zt_pool_df.copy()

    if data_frame_util.is_empty(ths_zt_pool_df_copy):
        return pd.DataFrame()
    if str_day == now_day_str_day:
        ths_zt_pool_df = merge_his_day_zt_info(ths_zt_pool_df_copy, str_day)
    else:
        ths_zt_pool_df = merge_his_day_zt_info(ths_zt_pool_df_copy, str_day)

    return ths_zt_pool_df


# 历史数据merge
def merge_his_day_zt_info(ths_zt_pool_df, str_day):
    '''
       获取请求头
       :param ths_zt_pool_df: 涨停df
       :param str_day: 日期
       :return:
       '''

    query_field = {
        "ths_concept_name": 1,
        "ths_concept_code": 1,
        "ths_concept_sync_day": 1,
        "company_type": 1,
        "concept_create_day": 1,
        "first_sw_industry": 1,
        "third_sw_industry": 1,
        "industry": 1,
        "list_date": 1,
    }
    query_field_key = str(query_field)
    query_key = str({'symbol': {"$in": list(ths_zt_pool_df['symbol'])}})
    company_df_zt = company_common_service_new_api.get_company_info_by_field(query_key, query_field_key)

    bfq_k_line_df = get_bfq_daily_line(ths_zt_pool_df, str_day)
    bfq_k_line_df['total_mv'] = bfq_k_line_df['flow_mv']

    company_df_zt = company_df_zt.set_index(['_id'], drop=True)
    bfq_k_line_df = bfq_k_line_df.set_index(['symbol'], drop=True)
    ths_zt_pool_df = ths_zt_pool_df.set_index(['symbol'], drop=False)

    if 'chg' in ths_zt_pool_df.columns:
        del ths_zt_pool_df['chg']
    if 'now_price' in ths_zt_pool_df.columns:
        del ths_zt_pool_df['now_price']

    ths_zt_pool_df = pd.merge(ths_zt_pool_df, company_df_zt, how='outer',
                              left_index=True, right_index=True)

    ths_zt_pool_df = pd.merge(ths_zt_pool_df, bfq_k_line_df, how='outer',
                              left_index=True, right_index=True)
    ths_zt_pool_df = common_service_fun_api.classify_symbol(ths_zt_pool_df)
    ths_zt_pool_df = common_service_fun_api.total_mv_classification(ths_zt_pool_df)
    ths_zt_pool_df.fillna('', inplace=True)
    if 'zt_flag' in ths_zt_pool_df.columns:
        del ths_zt_pool_df['zt_flag']
    if 'zt_tag' in ths_zt_pool_df.columns:
        del ths_zt_pool_df['zt_tag']

    return ths_zt_pool_df


# 获取不复权k线信息
def get_bfq_daily_line(ths_zt_pool_df, str_day):
    query_k_line = {'symbol': {"$in": list(ths_zt_pool_df['symbol'])}, 'date': date_handle_util.no_slash_date(str_day)}
    bfq_daily_line_df = mongodb_util.find_query_data('stock_bfq_daily', query_k_line)
    if bfq_daily_line_df.shape[0] >= ths_zt_pool_df.shape[0]:
        bfq_daily_line_df = bfq_daily_line_df[['amount', 'chg', 'close', 'exchange',
                                               'symbol', 'amount_level',
                                               'flow_mv', 'flow_mv_sp'
                                               ]]
        bfq_daily_line_df = bfq_daily_line_df.rename(columns={"close": 'now_price'})
        return bfq_daily_line_df
    else:
        bfq_k_line_result_df = pd.DataFrame()
        for zt_one in ths_zt_pool_df.itertuples():
            symbol = zt_one.symbol
            try:

                bfq_daily_line_df = k_line_common_api.get_k_line_common_adapter(symbol, 'daily', '', str_day)

                if data_frame_util.is_empty(bfq_daily_line_df):
                    continue

                bfq_daily_line_df_one = bfq_daily_line_df.loc[
                    bfq_daily_line_df['date'] == date_handle_util.no_slash_date(str_day)]

                bfq_daily_line_df_one = bfq_daily_line_df_one[['amount', 'chg', 'close', 'exchange',
                                                               'symbol', 'amount_level',
                                                               'flow_mv', 'flow_mv_sp'
                                                               ]]
                bfq_daily_line_df_one = bfq_daily_line_df_one.rename(columns={"close": 'now_price'})
                bfq_k_line_result_df = pd.concat([bfq_k_line_result_df, bfq_daily_line_df_one])
            except BaseException as e:
                logger.warning("同步不复权k线异常:{},{}", symbol, e)

        return bfq_k_line_result_df


def save_ths_zt_pool(ths_zt_pool_df, str_day):
    ths_zt_pool_df = ths_zt_pool_df[[
        "symbol",
        "name",
        "chg",
        "connected_boards_numbers",
        "statistics",
        "statistics_detail",
        "first_closure_time",
        "last_closure_time",
        "zt_detail",
        "zt_reason",
        "closure_volume",
        "closure_funds",
        "closure_funds_per_amount",
        "closure_funds_per_flow_mv",
        "frying_plates_numbers",
        "zt_type",
        "market_code",
        "str_day",
        "industry",
        "first_sw_industry",
        "third_sw_industry",
        "ths_concept_name",
        "ths_concept_code",
        "ths_concept_sync_day",
        "list_date",
        "company_type",
        "amount",
        "now_price",
        "exchange",
        "amount_level",
        "flow_mv",
        "flow_mv_sp",
        "total_mv",
        "classification",
        "total_mv_sp",
        "flow_mv_level"
    ]]
    ths_zt_pool_df['_id'] = ths_zt_pool_df['symbol'] + '_' + ths_zt_pool_df['str_day']
    ths_zt_pool_df = ths_zt_pool_df.sort_values(by=['connected_boards_numbers'], ascending=False)

    # 将日期数值转换为日期时间格式
    ths_zt_pool_df['list_date_01'] = pd.to_datetime(ths_zt_pool_df['list_date'], format='%Y%m%d')
    str_day_date = date_handle_util.str_to_date(str_day, '%Y-%m-%d')
    # 计算日期差值 距离现在上市时间
    ths_zt_pool_df['diff_days'] = ths_zt_pool_df.apply(
        lambda row: (str_day_date - row['list_date_01']).days, axis=1)
    del ths_zt_pool_df['list_date_01']

    mongodb_util.save_mongo(ths_zt_pool_df, db_name_constant.THS_ZT_POOL)


if __name__ == '__main__':
    # trade_date = '2024-08-01'
    # zt_df = ths_zt_pool(trade_date, None)
    # save_ths_zt_pool(zt_df, trade_date)
    trade_date = '2025-09-05'
    ths_zt_pool_df_test = ths_zt_pool(trade_date, None)
    save_ths_zt_pool(ths_zt_pool_df_test, trade_date)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import requests
import pandas as pd
from datetime import datetime
import mns_common.component.self_choose.black_list_service_api as black_list_service_api
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.constant.black_list_classify_enum import BlackClassify

mongodb_util = MongodbUtil('27017')
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api


# 立案调查股票
# http://www.cninfo.com.cn/new/commonUrl/pageOfSearch?url=disclosure/list/search&lastPage=index

def sync_investigate_stocks_api(page_num, page_size, search_key, begin_day, end_day):
    url = ('http://www.cninfo.com.cn/new/hisAnnouncement/query?'
           'pageNum=' + str(page_num) +
           '&pageSize=' + str(page_size) +
           '&column=szse&tabName=fulltext&plate=&stock=&searchkey=' + search_key +
           '&secid=&category=&trade=&seDate=' + begin_day +
           '~' + end_day +
           '&sortName=&sortType=&isHLtitle=true')

    headers = {
        "Content-Type": "application/json"
    }
    r = requests.post(url, headers=headers)
    data_json = r.json()
    total_record_num = data_json['totalRecordNum']
    data_list = data_json['announcements']
    data_df = pd.DataFrame(data_list)
    result = {'total_record_num': total_record_num,
              'data_df': data_df}
    return result


def sync_all_investigate_stocks(page_size, search_key, begin_day, end_day):
    page_num = 1
    data_result_df = None
    while True:
        result = sync_investigate_stocks_api(page_num, page_size, search_key, begin_day, end_day)
        data_df = result['data_df']
        if data_result_df is None:
            data_result_df = data_df
        else:
            data_result_df = pd.concat([data_df, data_result_df])

        if data_df.shape[0] < page_size:
            break
        page_num = page_num + 1
    return data_result_df


# 立案调查的股票
def sync_register_and_investigate_stocks():
    before_days = 60
    const_num = 30
    init_date = datetime.now()
    str_day = init_date.strftime('%Y-%m-%d')
    # 过去30天新增风险股票
    begin_date = date_handle_util.add_date_day(date_handle_util.no_slash_date(str_day), -before_days)
    begin_day = begin_date.strftime('%Y-%m-%d')
    search_key = '立案'

    end_date = date_handle_util.add_date_day(date_handle_util.no_slash_date(str_day), 1)
    end_day = end_date.strftime('%Y-%m-%d')
    new_high_risk_stocks_df = sync_all_investigate_stocks(const_num, search_key, begin_day, end_day)
    if data_frame_util.is_empty(new_high_risk_stocks_df):
        return None
    new_high_risk_stocks_df = new_high_risk_stocks_df.sort_values(by=['announcementTime'], ascending=False)
    de_list_company_symbols = company_common_service_new_api.get_de_list_company()
    for high_risk_stocks_one in new_high_risk_stocks_df.itertuples():
        try:
            symbol = high_risk_stocks_one.secCode
            if symbol in de_list_company_symbols:
                continue
            announcement_id = high_risk_stocks_one.announcementId

            key_id = symbol + "_" + str(announcement_id)
            query_exist = {"_id": key_id}
            if mongodb_util.exist_data_query(db_name_constant.SELF_BLACK_STOCK,
                                             query_exist):
                continue
            else:
                announcement_time = high_risk_stocks_one.announcementTime
                # 将毫秒转换为秒
                seconds = announcement_time // 1000
                # 使用datetime模块从秒转换为日期
                announce_date = datetime.fromtimestamp(seconds)
                announce_str_day = announce_date.strftime('%Y-%m-%d')
                announce_time = announce_date.strftime('%Y-%m-%d %H:%M:%S')
                announce_url = ('http://www.cninfo.com.cn/new/disclosure/detail?stockCode=' + str(symbol) +
                                '&announcementId=' + str(announcement_id) +
                                '&orgId=' + str(high_risk_stocks_one.orgId) +
                                '&announcementTime=' + announce_str_day)

                black_list_service_api.save_black_stock(
                    key_id,
                    symbol,
                    high_risk_stocks_one.secName,
                    announce_str_day,
                    announce_time,
                    high_risk_stocks_one.announcementTitle,
                    high_risk_stocks_one.announcementTitle,
                    announce_url,
                    BlackClassify.MAJOR_VIOLATIONS.up_level_code,
                    BlackClassify.MAJOR_VIOLATIONS.up_level_name,
                    BlackClassify.REGISTER_INVESTIGATE.level_code,
                    BlackClassify.REGISTER_INVESTIGATE.level_name,
                )
        except Exception as e:
            logger.error("保存风险警示股票异常:{},{}", symbol, e)


if __name__ == '__main__':
    sync_register_and_investigate_stocks()
    # result_df = sync_all_investigate_stocks(30, '立案', '2023-01-01', '2024-06-15')
    # result_df = result_df.sort_values(by=['announcementTime'], ascending=False)
    # print(result_df)



import sys
import os
import mns_common.api.kpl.selection.kpl_selection_plate_api as selection_plate_api
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
from datetime import datetime
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.msg.push_msg_api as push_msg_api
import time as sleep_time
import threading
import pandas as pd

import mns_common.api.kpl.constant.kpl_constant as kpl_constant

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

mongodb_util = MongodbUtil('27017')
# 定义一个全局锁，用于保护 result 变量的访问
result_lock = threading.Lock()
# 初始化 result 变量为一个空的 Pandas DataFrame
result = pd.DataFrame()

# 同步精选指数
file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
# 分页大小
MAX_PAGE_NUMBER = 10


# 获取精选一级指数
def choose_field_choose_first_index():
    data_df = selection_plate_api.best_choose()
    data_df['_id'] = data_df['plate_code']
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    data_df['sync_str_day'] = str_day
    data_df['sync_str_time'] = str_now_date
    data_df['index_class'] = kpl_constant.FIRST_INDEX
    return data_df


# 多线程分片同步
def multithread_shard_sync_index(first_kpl_df, page_number):
    global result
    for first_kpl_one in first_kpl_df.itertuples():
        try:
            kpl_best_choose_sub_index_detail = selection_plate_api.best_choose_sub_index(first_kpl_one.plate_code)
            if data_frame_util.is_not_empty(kpl_best_choose_sub_index_detail):
                # 保存第二级精选指数
                sync_best_choose_second_index(kpl_best_choose_sub_index_detail, first_kpl_one.plate_code)
                sub_plate_code_list = kpl_best_choose_sub_index_detail.to_string(index=False)
                # 更新第一级和第二级指数关联关系
                update_first_index_sub_index(first_kpl_one.plate_code, sub_plate_code_list)
                first_kpl_df.loc[
                    first_kpl_df['plate_code'] == first_kpl_one.plate_code, "sub_plate_code_list"] = sub_plate_code_list

        except BaseException as e:
            logger.error("处理一级精选指数异常:{}", e)
    with result_lock:
        # 使用锁来保护 result 变量的访问，将每页的数据添加到结果中
        result = pd.concat([result, first_kpl_df], ignore_index=True)


# 同步第一和第二级别精选指数  更新一级和二级之间的关联关系
def sync_best_choose_index():
    global result
    result = pd.DataFrame()  # 重新初始化 result 变量
    first_index_df = choose_field_choose_first_index()
    first_index_df.loc[:, "sub_plate_code_list"] = '-'

    count = first_index_df.shape[0]
    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
    page_number = int(page_number)

    threads = []

    # 创建多个线程来获取数据
    for page in range(page_number):  # 0到100页
        end_count = (page + 1) * MAX_PAGE_NUMBER
        begin_count = page * MAX_PAGE_NUMBER
        page_df = first_index_df.iloc[begin_count:end_count]
        thread = threading.Thread(target=multithread_shard_sync_index, args=(page_df, page_number))
        threads.append(thread)
        thread.start()

        # 等待所有线程完成
    for thread in threads:
        thread.join()

    exist_code_df = mongodb_util.find_query_data_choose_field('kpl_best_choose_index',
                                                              {},
                                                              {"plate_code": 1})

    if data_frame_util.is_not_empty(exist_code_df):
        exist_code_list = list(exist_code_df['plate_code'])
        new_data_df = result.loc[~(result['plate_code'].isin(exist_code_list))]
    else:
        new_data_df = result.copy()

    if data_frame_util.is_empty(new_data_df):
        return None
    # 处理一级指数
    handle_new_kpl_index(new_data_df, kpl_constant.FIRST_INDEX, None)
    return result


# 处理新增指数数据
def handle_new_kpl_index(new_data_df, index_class, first_plate_code):
    for new_data_one in new_data_df.itertuples():
        try:
            concept_code = new_data_one.plate_code
            concept_name = new_data_one.plate_name
            msg = "概念代码:" + str(concept_code) + "," + "概念名称:" + concept_name + ",指数级别" + index_class
            title = "新增开盘啦精选概念:" + str(concept_code) + "-" + concept_name
            push_msg_api.push_msg_to_wechat(title, msg)
            sleep_time.sleep(1)
        except BaseException as e:
            logger.error("推送出现异常:{}", e)
    # 保存新数据
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    if first_plate_code is not None:
        new_data_df['first_plate_code'] = first_plate_code
    else:
        new_data_df['first_plate_code'] = new_data_one.plate_code

    new_data_df['create_day'] = str_day
    new_data_df['create_time'] = str_now_date
    new_data_df.loc[:, "create_day"] = str_day
    new_data_df.loc[:, "create_time"] = str_now_date
    new_data_df.loc[:, "valid"] = True
    new_data_df = new_data_df[["_id",
                               "plate_code",
                               "plate_name",
                               "heat_score",
                               "index_class",
                               "sync_str_day",
                               "sync_str_time",
                               "create_day",
                               "create_time",
                               "first_plate_code",
                               "valid"]]
    mongodb_util.insert_mongo(new_data_df, 'kpl_best_choose_index')


# 更新第一级精选指数 次级指数关系
def update_first_index_sub_index(first_plate_code, sub_plate_code_list):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    new_values = {"$set": {"sub_plate_code_list": sub_plate_code_list,
                           "sync_str_day": str_day,
                           "sync_str_time": str_now_date}}
    query = {'plate_code': first_plate_code}
    mongodb_util.update_many(query, new_values, "kpl_best_choose_index")


# 同步二级精选指数
def sync_best_choose_second_index(kpl_best_choose_sub_index_detail, first_plate_code):
    kpl_best_choose_sub_index_detail['_id'] = kpl_best_choose_sub_index_detail['plate_code']
    kpl_best_choose_sub_index_detail['index_class'] = kpl_constant.SUB_INDEX
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    sync_str_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    kpl_best_choose_sub_index_detail['sync_str_day'] = str_day
    kpl_best_choose_sub_index_detail['sync_str_time'] = sync_str_date

    exist_code_df = mongodb_util.find_query_data_choose_field('kpl_best_choose_index',
                                                              {},
                                                              {"plate_code": 1})

    if data_frame_util.is_not_empty(exist_code_df):
        exist_code_list = list(exist_code_df['plate_code'])
        new_data_df = kpl_best_choose_sub_index_detail.loc[
            ~(kpl_best_choose_sub_index_detail['plate_code'].isin(exist_code_list))]
    else:
        new_data_df = kpl_best_choose_sub_index_detail.copy()
    if data_frame_util.is_empty(new_data_df):
        return None

    handle_new_kpl_index(new_data_df, kpl_constant.SUB_INDEX, first_plate_code)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.kpl.common.kpl_common_api as kpl_common_api
from loguru import logger
from datetime import datetime, timedelta
import pandas as pd

mongodb_util = MongodbUtil('27017')


# 更新所有概念入选原因
def update_all_kpl_symbol_choose_reason():
    kpl_best_choose_index_df = mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX, {})
    for concept_one in kpl_best_choose_index_df.itertuples():
        try:
            concept_code = concept_one.plate_code
            kpl_best_choose_index_detail_df = mongodb_util.find_query_data(
                db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL, {"plate_code": concept_code})
            if data_frame_util.is_not_empty(kpl_best_choose_index_detail_df):
                kpl_symbol_list = list(kpl_best_choose_index_detail_df['symbol'])
                symbol_str = ','.join(kpl_symbol_list)
                choose_reason_df = kpl_common_api.get_kpl_concept_choose_reason(concept_code, symbol_str)
                if data_frame_util.is_not_empty(choose_reason_df):
                    for choose_reason_one in choose_reason_df.itertuples():
                        symbol = choose_reason_one.symbol
                        try:

                            choose_reason = choose_reason_one.choose_reason
                            update_query = {'symbol': symbol, 'plate_code': concept_code}
                            new_values = {"$set": {"long": choose_reason}}
                            mongodb_util.update_many(update_query, new_values,
                                                     db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL)
                        except BaseException as e:
                            logger.error("更新开票啦入选原因异常:{},{},{}", symbol, concept_code, e)
            logger.info("更新开票啦入选原因完成:{},{}", concept_one.plate_code, concept_one.plate_name)
        except BaseException as e:
            logger.error("更新开票啦入选原因异常:{},{},{}", concept_one.plate_code, concept_one.plate_name, e)


# 更新入选概念原因
def update_symbol_new_concept_reason(plate_code, kpl_symbol_list):
    symbol_str = ','.join(kpl_symbol_list)
    choose_reason_df = kpl_common_api.get_kpl_concept_choose_reason(plate_code, symbol_str)
    if data_frame_util.is_not_empty(choose_reason_df):
        choose_reason_df = choose_reason_df[choose_reason_df['choose_reason'] != '']
        if data_frame_util.is_empty(choose_reason_df):
            return
        for choose_reason_one in choose_reason_df.itertuples():
            symbol = choose_reason_one.symbol
            try:

                choose_reason = choose_reason_one.choose_reason
                update_query = {'symbol': symbol, 'plate_code': plate_code}
                new_values = {"$set": {"long": choose_reason}}
                mongodb_util.update_many(update_query, new_values,
                                         db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL)
            except BaseException as e:
                logger.error("更新开票啦入选原因异常:{},{},{}", symbol, plate_code, e)


def update_null_choose_reason():
    # 获取当前日期时间
    now = datetime.now()

    # 计算前15天的日期时间
    days_ago_15 = now - timedelta(days=30)

    # 按指定格式输出
    formatted_date = days_ago_15.strftime("%Y-%m-%d %H:%M:%S")
    query = {"create_time": {"$gte": formatted_date}, '$or': [{"long": {"$exists": False}}, {"long": ''}]}
    null_choose_reason_detail_df = mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL, query)
    if data_frame_util.is_not_empty(null_choose_reason_detail_df):
        grouped_null_reason_df = null_choose_reason_detail_df.groupby('plate_code')
        grouped_null_reason_list = grouped_null_reason_df.size()
        group_null_reason = pd.DataFrame(grouped_null_reason_list, columns=['number'])
        group_null_reason['plate_code'] = group_null_reason.index
        group_null_reason = group_null_reason.sort_values(by=['number'], ascending=False)
        for null_reason_one in group_null_reason.itertuples():
            plate_code = null_reason_one.plate_code
            try:

                null_reason_one_plate_df = null_choose_reason_detail_df.loc[
                    null_choose_reason_detail_df['plate_code'] == plate_code]
                kpl_symbol_list = list(null_reason_one_plate_df['symbol'])
                update_symbol_new_concept_reason(plate_code, kpl_symbol_list)
                logger.info("更新开票啦入选原因完成:{},{}", null_reason_one.plate_code,
                            list(null_reason_one_plate_df['plate_name'])[0])
            except BaseException as e:
                logger.error("更新kpl入选原因异常:{},{}", null_reason_one.plate_code, e)

    return formatted_date


if __name__ == '__main__':
    update_null_choose_reason()
    # update_all_kpl_symbol_choose_reason()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.concept.app.ths_concept_index_app as ths_concept_index_app
import mns_scheduler.concept.ths.common.ths_concept_sync_common_api as ths_concept_sync_common_api
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger
import mns_common.api.ths.concept.web.ths_concept_index_web as ths_concept_index_web
from mns_common.db.MongodbUtil import MongodbUtil
from datetime import datetime
import mns_scheduler.concept.clean.ths_concept_clean_api as ths_concept_clean_api
import pandas as pd
import mns_scheduler.concept.ths.detaill.ths_concept_detail_api as ths_concept_detail_api
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.component.redis_msg.redis_msg_publish_service as redis_msg_publish_service
import mns_common.constant.redis_msg_constant as redis_msg_constant

mongodb_util = MongodbUtil('27017')
import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api


def sync_ths_concept_new_index():
    # 同步ths新概念 通过app搜索
    sync_ths_concept_new_index_from_app()
    # 通过ths详情搜索
    sync_ths_concept_new_index_from_detail()


'''
同步ths新概念 通过app搜索代码
'''


def sync_ths_concept_new_index_from_app():
    # 当前最大概念代码
    max_concept_code = int(ths_concept_sync_common_api.get_max_concept_code())
    # 最大概念代码上限
    max_concept_code_limit = max_concept_code + 2
    # 同花顺概念列表
    ths_concept_list_exist = ths_concept_common_service_api.get_all_ths_concept()
    # 同步向上3次
    while max_concept_code <= max_concept_code_limit:
        try:
            max_concept_code = max_concept_code + 1
            concept_new_index_df = ths_concept_index_app.get_new_concept_from_app_search(max_concept_code)
            if data_frame_util.is_empty(concept_new_index_df):
                continue
            concept_name = list(concept_new_index_df['concept_name'])[0]

            if data_frame_util.is_string_empty(concept_name):
                concept_name = ths_concept_index_web.get_concept_name(max_concept_code)

            exist_concept_df_one = ths_concept_list_exist.loc[
                (ths_concept_list_exist['symbol'] == max_concept_code)
                | (ths_concept_list_exist['web_concept_code'] == max_concept_code)]
            now_date = datetime.now()
            str_now_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
            str_day = now_date.strftime('%Y-%m-%d')
            if data_frame_util.is_empty(exist_concept_df_one):
                concept_code = max_concept_code

                url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
                new_concept_one = {
                    '_id': int(concept_code),
                    'symbol': int(concept_code),
                    'name': concept_name,
                    'url': url,
                    'str_day': str_day,
                    'success': True,
                    'str_now_time': str_now_time,
                    'web_concept_code': concept_code,
                    'web_concept_url': url,
                    'valid': True,
                    'grade': 1,
                    'remark': ''
                }
                diff_one_df = pd.DataFrame(new_concept_one, index=[1])
                # 保存新增概念信息
                mongodb_util.save_mongo(diff_one_df, db_name_constant.THS_CONCEPT_LIST)
                # 新增概念信息处理 推送到微信
                ths_concept_sync_common_api.push_msg_to_we_chat_and_redis(concept_code, concept_name,
                                                                          url)
                #    同步概念详情到db
                ths_concept_detail_api.sync_ths_concept_detail_to_db(concept_code, concept_name)
                # 更新ths概念统计信息
                ths_concept_clean_api.update_ths_concept_info()

                logger.info("新增同花顺新概念:{}", concept_name)

        except BaseException as e:
            logger.error("同步新增概念代码:{},信息异常:{}", max_concept_code, e)


'''
同步新概念 by ths detail 通过详情判断
'''


def sync_ths_concept_new_index_from_detail():
    # 当前最大概念代码
    max_concept_code = ths_concept_sync_common_api.get_max_concept_code()
    # 最大概念代码上线
    max_concept_code_limit = max_concept_code + 2
    # 同花顺概念列表
    ths_concept_list_exist = mongodb_util.find_all_data(db_name_constant.THS_CONCEPT_LIST)
    # 同步向上3次
    while max_concept_code <= max_concept_code_limit:
        try:
            max_concept_code = max_concept_code + 1
            concept_code = max_concept_code
            concept_name = ths_concept_index_web.get_concept_name(concept_code)
            new_concept_symbol_detail_df = ths_concept_detail_api.get_ths_concept_detail(concept_code, concept_name)
            if data_frame_util.is_empty(new_concept_symbol_detail_df):
                continue

            exist_concept_df_one = ths_concept_list_exist.loc[
                (ths_concept_list_exist['symbol'] == concept_code)
                | (ths_concept_list_exist['web_concept_code'] == concept_code)]
            now_date = datetime.now()
            str_now_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
            str_day = now_date.strftime('%Y-%m-%d')
            if data_frame_util.is_empty(exist_concept_df_one):
                concept_code = max_concept_code

                url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
                new_concept_one = {
                    '_id': int(concept_code),
                    'symbol': int(concept_code),
                    'name': concept_name,
                    'url': url,
                    'str_day': str_day,
                    'success': True,
                    'str_now_time': str_now_time,
                    'web_concept_code': concept_code,
                    'web_concept_url': url,
                    'valid': True,
                    'grade': 1,
                    'remark': ''
                }
                diff_one_df = pd.DataFrame(new_concept_one, index=[1])
                mongodb_util.save_mongo(diff_one_df, db_name_constant.THS_CONCEPT_LIST)
                # 新增概念信息处理
                ths_concept_sync_common_api.push_msg_to_we_chat_and_redis(concept_code, concept_name,
                                                                          url)

                new_concept_symbol_detail_df.loc[:, 'way'] = 'index_sync'
                ths_concept_sync_common_api.save_ths_concept_detail(new_concept_symbol_detail_df,
                                                                    concept_name,
                                                                    str_day,
                                                                    str_now_time,
                                                                    concept_code)

                logger.info("新增同花顺新概念:{}", concept_name)

        except BaseException as e:
            logger.error("同步新增概念代码:{},信息异常:{}", max_concept_code, e)
    # 更新ths概念统计信息
    ths_concept_clean_api.update_ths_concept_info()
    # 项目之间推送消息
    redis_msg_publish_service.send_redis_msg(redis_msg_constant.THS_CONCEPT_MSG_TOPIC,
                                             redis_msg_constant.THS_NEW_CONCEPT_ADD_MSG)


if __name__ == '__main__':
    sync_ths_concept_new_index()
